# ==================================================================
# Plugins::GForum::Whoelse - Auto Generated Install Module
#
#   Plugins::GForum::Whoelse
#   Author  : ellipsiiis@ellipsiiis.com
#   Version : 1.0.0
#   Updated : Fri Feb 15 14:57:01 2002
#
# ==================================================================
#

package Plugins::GForum::Whoelse;
# ==================================================================
use strict;
use vars  qw/$VERSION $DEBUG $NAME $META/;
use GT::Base;
use GT::Plugins qw/STOP CONTINUE/;
use GForum qw/$IN $DB $CFG/;

$VERSION = '1.0';
$DEBUG   = 0;
$NAME    = 'Whoelse';
# Inhert from base class for debug and error methods
@Plugins::GForum::Whoelse::ISA = qw(GT::Base);

$META = {
    'author' => 'ellipsiiis.com',
    'url' => 'http://www.ellipsiiis.com',
    'license' => 'Freeware',
    'description' => 'This plugin allows you to search for users/posts with a certain IP.',
    'prog_ver' => '1.0.0',
    'version' => '1.0'
};


sub pre_install {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they install
# the plugin.
#
    my $inst_msg = 'This will install the functionality to add a link to your include_post_display.html template that allows administrators to view who else is using that post\'s IP address.

You will have to add the link to include_post_display.html yourself, but you can copy this Template HTML:

&lt;a href="gforum.cgi?do=whoelse;ip=&lt;%post_ip%&gt;"&gt;Whoelse&lt;/a&gt;';

    return $inst_msg;
}

sub pre_uninstall {
# -------------------------------------------------------------------
# This function displays an HTML formatted message that will display
# to the user any instructions/information before they remove the
# plugin.
#
    my $uninst_msg = 'You are uninstalling the Whoelse plugin. If you have created a link in include_post_display.html, you should remove that link. Any links clicked once this module has been removed will result in an "Invalid Action" error message.';
    return $uninst_msg;
}

sub install {
# -------------------------------------------------------------------
# This function does the actual installation. It's first argument is
# a plugin manager which you can use to register hooks, install files,
# add menu options, etc. The second argument is a GT::Tar object which
# you can use to access any files in your plugin module.
#
# You should return an HTML formatted string that will be displayed 
# to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::GForum::Whoelse::error
#
    my ($mgr, $tar) = @_;
    
# Silence warnings
    $GT::Tar::error ||= '';

# Copying whoelse.html to $CFG->{admin_root_path} directory.
    my $path = "$CFG->{admin_root_path}/templates/default/local/whoelse.html";
    my $file = $tar->get_file ('whoelse.html');
    $file->name($path);
    $file->write or return Whoelse->error("Unable to extract file: '$path' ($GT::Tar::error)", 'WARN');
    chmod (0666, $path);

# Add the whoelse function to the config. This enables running do=whoelse and only allows moderator
# groups access.
    $CFG->{functions}->{whoelse} = {
        action => 'function',
        customizable => {
            description => '1',
            page => '1',
            hidden => '1',
        },
        hidden => 1,
        description => 'Whoelse uses this IP?',
        function => 'Plugins::GForum::Whoelse::whoelse',
        user_groups => {
                $CFG->{id_group_moderator} => '1'
        },
        page => {
            whoelse => 'whoelse.html'
        }
    };
    $CFG->save();


    return "The plugin has been successfully installed!";
}

sub uninstall {
# -------------------------------------------------------------------
# This function removes the plugin. It's first argument is
# also a plugin manager which you can use to register hooks, install files,
# add menu options, etc. You should return an HTML formatted string
# that will be displayed to the user.
#
# If there is an error, return undef, and set the error message in
# $Plugins::GForum::Whoelse::error
#
    my $mgr = shift;    
    delete $CFG->{functions}->{whoelse};
    $CFG->save();

    return "The plugin has been successfully removed!";
}

1;
